@@ -1,5 +1,5 @@
 """
-Test if a variable name is valid
+This module contains code to validate variable/argument/parameter names or to make them valid ones.
 """
 
 import builtins
@@ -10,12 +10,22 @@ from string import ascii_letters, digits
 from pytest_csv_params.exception import CsvHeaderNameInvalid
 
 VALID_CHARS = ascii_letters + digits
+"""
+Valid characters a variable/parameter/argument name can consist of
+"""
+
 VARIABLE_NAME = re.compile(r"^[a-zA-Z_][A-Za-z0-9_]{0,1023}$")
+"""
+Regular expression that defines a valid variable/parameter/argument name
+"""
 
 
 def is_valid_name(name: str) -> bool:
     """
     Checks if the variable name is valid
+
+    :param name: The name to be checked
+    :returns: `True`, when the name is valid
     """
     if (
         keyword.iskeyword(name)
@@ -28,7 +38,12 @@ def is_valid_name(name: str) -> bool:
 
 def make_name_valid(name: str, replacement_char: str = "_") -> str:
     """
-    Make a name valid
+    Make a name a valid name by replacing invalid chars with the as :attr:`replacement_char` given char
+
+    :param name: The name to make a valid one
+    :param replacement_char: The char to replace invalid chars with, default is an underscore `_`
+    :returns: A valid name
+    :raises CsvHeaderNameInvalid: If the fixed name is still an invalid name
     """
 
     fixed_name = name
