@@ -1,5 +1,8 @@
 """
-Check Version Information
+This module contains two methods to check if the python version is recent enough (:meth:`check_python_version`) and if
+the pytest version is recent enough (:meth:`check_pytest_version`).
+
+During the setup phase of the plugin (see :mod:`pytest_csv_params.plugin`) these methods are called.
 """
 import sys
 from typing import Tuple
@@ -11,6 +14,9 @@ from packaging.version import parse
 def check_python_version(min_version: Tuple[int, int] = (3, 8)) -> None:
     """
     Check if the current version is at least 3.8
+
+    :param min_version: The minimum version required, as tuple, default is 3.8
+    :raises PythonTooOldError: When the python version is too old/unsupported
     """
 
     if sys.version_info < min_version:
@@ -20,6 +26,9 @@ def check_python_version(min_version: Tuple[int, int] = (3, 8)) -> None:
 def check_pytest_version(min_version: Tuple[int, int] = (7, 1)) -> None:
     """
     Check if the current version is at least 7.1
+
+    :param min_version: The minimum version required, as tuple, default is 7.1
+    :raises RuntimeError: When the pytest version is too old/unsupported
     """
 
     from pytest import __version__ as pytest_version  # pylint: disable=import-outside-toplevel
